Package: alabaster.ranges
Title: Load and Save Ranges-related Artifacts from File
Version: 1.12.0
Date: 2025-07-22
Authors@R: person("Aaron", "Lun", role=c("aut", "cre"), email="infinite.monkeys.with.keyboards@gmail.com")
License: MIT + file LICENSE
Description: 
    Save GenomicRanges, IRanges and related data structures into file artifacts, and load them back into memory.
    This is a more portable alternative to serialization of such objects into RDS files.
    Each artifact is associated with metadata for further interpretation;
    downstream applications can enrich this metadata with context-specific properties.
Depends: GenomicRanges, alabaster.base
Imports: methods, S4Vectors, BiocGenerics, IRanges, Seqinfo, rhdf5
Suggests: testthat, knitr, BiocStyle, jsonlite
VignetteBuilder: knitr
RoxygenNote: 7.2.3
biocViews: DataImport, DataRepresentation
git_url: https://git.bioconductor.org/packages/alabaster.ranges
git_branch: RELEASE_3_23
git_last_commit: 7941158
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 20:33:17 UTC; biocbuild
Author: Aaron Lun [aut, cre]
Maintainer: Aaron Lun <infinite.monkeys.with.keyboards@gmail.com>
